# $Id$

package Google::Chart::Type::Line;
use Moose;
use constant parameter_value => 'lc';

with 'Google::Chart::Type::Simple';

no Moose;

1;

__END__

=head1 NAME

Google::Chart::Type::Line - Google::Chart Line Type

=cut