# $Id$

package Google::Chart::Type::ScatterPlot;
use Moose;
use constant parameter_value => 's';

with 'Google::Chart::Type::Simple';

__PACKAGE__->meta->make_immutable;

no Moose;

1;

__END__

=head1 NAME 

Google::Chart::Type::ScatterPlot - Google::Chart ScatterPlot Type

=cut
